pub trait Encoder {
type Item;
type Error: From<Error>;
// Required method
fn encode(
&mut self,
item: Self::Item,
dst: &mut BytesMut,
) -> Result<(), Self::Error>;
}Expand description
Trait of helper objects to write out messages as bytes, for use with
FramedWrite.
Required Associated Types
Required Methods
Sourcefn encode(
&mut self,
item: Self::Item,
dst: &mut BytesMut,
) -> Result<(), Self::Error>
fn encode( &mut self, item: Self::Item, dst: &mut BytesMut, ) -> Result<(), Self::Error>
Encodes a frame into the buffer provided.
This method will encode item into the byte buffer provided by dst.
The dst provided is an internal buffer of the Framed instance and
will be written out when possible.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".